@@ -3,7 +3,7 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.15";
+our $VERSION = "0.16";
 
 our $draft         = "17";
 our $draft_interop = "14";
@@ -61,9 +61,9 @@ plain or tls socket (see examples).
 
 =head1 STATUS
 
-Current status - alpha. Structures, module names and methods may change vastly.
+Current status - beta. Structures, module names and methods seems like stable.
 I've started this project to understand internals of HTTP/2 and may be it will
-never become production or even finished.
+never become production, but at least it works.
 
     | Spec                    |      status     |
     | ----------------------- | --------------- |
@@ -126,14 +126,20 @@ L<http://tools.ietf.org/html/draft-ietf-httpbis-header-compression-12>
 
 =head2 L<Protocol::HTTP2::Constants>
 
-Module contain all defined in HTTP/2 protocol constants and default values
+Module contains all defined in HTTP/2 protocol constants and default values
 
 =head2 L<Protocol::HTTP2::Trace>
 
-Module for debugging. (Ab)used Log::Dispatch internally, may be removed soon.
+Module for debugging. You can setup HTTP2_DEBUG environment variable to change
+verbosity of the module (output to STDOUT). Default level is error.
+
+    $ export HTTP2_DEBUG=debug
+    $ perl ./http2_program
 
 =head1 SEE ALSO
 
+L<https://github.com/vlet/p5-Protocol-HTTP2/wiki> - Protocol::HTTP2 wiki
+
 L<http://http2.github.io/> - official HTTP/2 specification site
 
 L<http://daniel.haxx.se/http2/> - http2 explained
